@@ -11,11 +11,11 @@ from .node import (
 )
 from .registry import ConfigRegistry
 from .utils import merge_nested_dicts, FUTURE
-from .instantiate import get_callable
+from .instantiate import TargetType
 
 
 @ConfigRegistry.add
-def __is_type__(*args, **kwargs) -> str:
+def __is_type__(*args, **_) -> str:
     """Check if the provided value matches the target type.
     Usage example:
 
@@ -32,7 +32,7 @@ def __is_type__(*args, **kwargs) -> str:
         raise ValueError(msg)
 
     node_source, target_type, *_ = args
-    target_type = get_callable(target_type)
+    target_type = TargetType.get_callable(target_type)
 
     if node_source == '${epochs}':
         raise ValueError()
@@ -80,7 +80,7 @@ def __environ__(*args, **kwargs) -> str:
 
 
 @ConfigRegistry.add
-def __timestamp__(*args, **kwargs) -> str:
+def __timestamp__(*_, **__) -> str:
     """Returns a timestamp in the format
     year-month-day_hour-minute-second."""
     return datetime.now(tz=timezone.utc).strftime("%Y-%m-%d_%H-%M-%S")
